-- set name and namespace
addonname, PAR=...

-- auras that cause misses (abilityIDs and ability names in comments)
PAR.MissAuras={
	260, -- 259 Invisibility, not related but keeping it here just in case
	340, -- 159 Burrow
	341, -- 170 Lift-Off, 588 Devastate, and 612 Proto-Strike
	737, -- 407 Meteor Strike
	830, -- 564 Dive
	839, -- 761 Heroic Leap
	852, -- 645 Launch
}

-- rejected abilities (ability names and reason for rejection in comments)
PAR.RejectedAbilities={
	190, -- Cyclone (aura): this ability does not cause "miss" events in the log when it misses
	476, -- Dark Simulacrum: NOT GONNA HAPPEN
}

-- conditional abilities (ability names and conditional state/effects in comments)
-- format is [abilityID]={effectIndex, ConditionalCheckType, StateIDofCondition, ConditionalModifier}
-- supported strings for ConditionalCheckType: "t", "c", "b", "w", "ft", and "fc"
PAR.ConditionalAbilities={
	[423]={[1]=1,[2]="t",[3]=77,[4]=50}, -- Blood in the Water: requires Bleeding for 100% accuracy, otherwise 50%
	[442]={[1]=1,[2]="t",[3]=82,[4]=50}, -- Spectral Strike: requires Blinded for 100% accuracy, otherwise 50%
	[517]={[1]=1,[2]="t",[3]=82,[4]=50}, -- Nocturnal Strike: requires Blinded for 100% accuracy, otherwise 50%
	[226]={[1]=3,[2]="t",[3]=82,[4]=95}, -- Fury of 1,000 Fists: requires Blinded for 95% stun chance, otherwise 0%
	[481]={[1]=3,[2]="t",[3]=52,[4]=75}, -- Deep Freeze: requires Chilled for 100% stun chance, otherwise 25%
	[769]={[1]=3,[2]="b",[3]=56,[4]=75}, -- Surge of Light: requires Darkness for 100% stun chance, otherwise 25%
}

-- stun abilities/effects (prevented by Arcane Storm)
-- Resilient does NOT cause "misses" so PAR can disregard it.
-- NOTE Multi-Turn Abilities that cause stuns are not listed because they are already ignored right now.
-- This may have to be fixed later.
PAR.StunAbilityEffects={
	[571]=2, -- Horn Attack (ignores Resilient), condition for mini-stun: user is faster
	[376]=3, -- Headbutt
	[669]=2, -- Backflip (ignores Resilient), condition for mini-stun chance: user goes first
	[348]=1, -- Bash
	[350]=1, -- Clobber
	[569]=1, -- Crystal Prison
	[227]=1, -- Blackout Kick
	[481]=3, -- Deep Freeze, condition for 100% accuracy on stun: target is chilled
	[226]=3, -- Fury of 1,000 Fists, condition for stun chance: target is blinded
	[654]=2, -- Ghostly Bite (ignores Resilient)
	[762]=2, -- Haymaker (ignores Resilient), condition for stun chance: user misses target
	[474]=2, -- Interrupting Gaze (ignores Resilient), condition for mini-stun: user goes first
	[938]=2, -- Interrupting Jolt (ignores Resilient), condition for mini-stun: user goes first
	[307]=2, -- Kick (ignores Resilient)
	[766]=1, -- Holy Justice
	[775]=3, -- Perfumed Arrow
	[814]=3, -- Rupture
	[754]=3, -- Screeching Gears
	[646]=3, -- Shock and Awe
	[752]=3, -- Soulrush
	[769]=3, -- Surge of Light, condition for 100% accuracy on stun: weather is darkness
	[772]=1, -- Lovestruck
}

-- root abilities/effects (prevented by Arcane Storm)
-- Resilient does NOT cause "misses" so PAR can disregard it.
-- NOTE Multi-Turn Abilities that cause roots are not listed because they are already ignored right now.
-- This may have to be fixed later.
PAR.RootAbilityEffects={
	[339]=2, -- Sticky Web
	[399]=2, -- Entangling Root (aura) (Turn 2)
}

-- multi-turn abilities
PAR.MultiTurnAbilities={
	[73]=2, -- Multi Turn Test
	[81]=3, -- Aura Bomb 75 Test
	[120]=2, -- Howling Blast
	[124]=3, -- Rampage
	[158]=3, -- Counterstrike
	[159]=2, -- Burrow
	[160]=2, -- Consume
	[163]=3, -- Stampede
	[169]=2, -- Deep Breath
	[170]=2, -- Lift-Off
	[175]=4, -- Volcano (aura)
	[198]=3, -- Zergling Rush
	[209]=3, -- Ion Cannon
	[217]=5, -- Curse of Doom (aura)
	[220]=2, -- Jacob's Test Aura
	[234]=2, -- Jacob's Test Aura 2
	[242]=2, -- Undead (passive)
	[246]=3, -- Hibernation (aura)
	[260]=3, -- Fading (aura)
	[274]=2, -- Wish (aura)
	[278]=3, -- Repair
	[280]=2, -- Overload (aura)
	[295]=3, -- GM Heal
	[328]=3, -- Eggs (aura)
	[329]=2, -- Hatchlings (aura)
	[381]=2, -- Brittle Webbing (aura)
	[383]=3, -- Leech Life
	[385]=4, -- XE-321 Boombot (aura)
	[387]=5, -- Tympanic Tantrum
	[399]=2, -- Entangling Roots (aura)
	[401]=3, -- Stun Seed (aura)
	[407]=2, -- Meteor Strike
	[417]=4, -- Geyser (aura)
	[439]=2, -- Onyx Wall
	[449]=2, -- Absorb
	[469]=3, -- Agony (aura)
	[472]=3, -- Blast of Hatred
	[476]=3, -- Dark Simulacrum
	[489]=3, -- Mana Surge
	[490]=3, -- Deflection
	[496]=3, -- Drowsy (aura)
	[498]=2, -- Asleep (aura)
	[509]=3, -- Surge
	[512]=3, -- Whirlpool (aura)
	[529]=3, -- Belly Slide
	[538]=2, -- Devour
	[540]=2, -- Chew (aura)
	[563]=3, -- Quick Attack
	[564]=2, -- Dive
	[568]=3, -- Feign Death
	[581]=3, -- Flock
	[588]=2, -- Devastate
	[593]=3, -- Surge of Power
	[599]=3, -- Emerald Dream (aura)
	[601]=3, -- Time Bomb (aura)
	[605]=3, -- Elementium Bolt (aura)
	[612]=2, -- Proto-Strike
	[616]=3, -- Blinkstrike
	[623]=3, -- Ice Tomb (aura)
	[633]=2, -- Confusing Sting (aura)
	[637]=2, -- Sticky Grenade (aura)
	[644]=5, -- Quake
	[645]=2, -- Launch
	[653]=2, -- Haunt (aura)
	[660]=2, -- Spreading Infection (aura)
	[661]=2, -- Spreading Infection (aura)
	[662]=2, -- Spreading Infection (aura)
	[668]=3, -- Dreadful Breath
	[671]=3, -- Snap Trap (aura)
	[706]=3, -- Swarm
	[714]=3, -- GM Revive
	[720]=2, -- Clone (aura)
	[734]=2, -- Crystal Prison (aura)
	[738]=2, -- Nevermore (aura)
	[747]=3, -- Spore Shrooms (aura)
	[753]=3, -- Solar Beam
	[761]=2, -- Heroic Leap
	[762]=3, -- Haymaker
	[767]=2, -- Holy Charge
	[770]=3, -- Restoration
	[773]=2, -- Shot Through The Heart
	[776]=3, -- Love Potion
	[778]=3, -- Charge
	[787]=2, -- Frostbite (aura)
	[798]=2, -- Dark Simulacrum (aura)
	[799]=2, -- Mrrrgglllrggghl (aura)
	[802]=2, -- Ravage
	[810]=3, -- Magma Trap (aura)
	[870]=3, -- Murder
	[916]=2, -- Haywire
	[921]=2, -- Hunting Party
	[926]=2, -- Asleep (aura)
	[927]=2, -- Stunned (aura)
	[937]=2, -- Siphon Anima
	[958]=3, -- Trihorn Charge
}